@@ -704,3 +704,7 @@ def distance_test(D_mat, change, num_perm = 1000):
     pval = 1 - (stat_rec > stat_rec[0] + pow(10, -6)).mean()
     return pval
 
+def DISTp(csn_mat, change, num_perm = 1000):
+    D_mat = create_D_mat(csn_mat)
+    pval = distance_test(D_mat, change = change, num_perm = num_perm)
+    return pval
\ No newline at end of file
